@@ -14,7 +14,6 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 from copy import copy, deepcopy
-from functools import partial
 import logging
 
 from gi.repository import GLib
@@ -150,8 +149,9 @@ class Device(object):
 
     def is_file(self, path):
         """Comparison by mount and device file path."""
-        return samefile(path, self.device_file) or any(
-            samefile(path, mp) for mp in self.mount_paths)
+        return (samefile(path, self.device_file) or
+                samefile(path, self.loop_file) or
+                any(samefile(path, mp) for mp in self.mount_paths))
 
     # availability of interfaces
     @property
@@ -187,6 +187,11 @@ class Device(object):
         """Check if the device is a LUKS container."""
         return bool(self._P.Encrypted)
 
+    @property
+    def is_loop(self):
+        """Check if the device is a loop device."""
+        return bool(self._P.Loop)
+
     # ----------------------------------------
     # Drive
     # ----------------------------------------
@@ -205,7 +210,7 @@ class Device(object):
         This method is used internally to unify the behaviour of top level
         devices in udisks1 and udisks2.
         """
-        return self.drive if self.is_toplevel else self
+        return self.drive if self.is_toplevel and not self.is_loop else self
 
     @property
     def is_detachable(self):
@@ -477,6 +482,15 @@ class Device(object):
             })
         )
 
+    # ----------------------------------------
+    # loop
+    # ----------------------------------------
+
+    @property
+    def loop_file(self):
+        """Get the file backing the loop device."""
+        return decode_ay(self._P.Loop.BackingFile)
+
     # ----------------------------------------
     # derived properties
     # ----------------------------------------
